@@ -1,4 +1,4 @@
-# This is file ../spam0.28-0/R/helper.R
+# This is file ../spam0.29-0/R/helper.R
 # This file is part of the spam package, 
 #      http://www.math.uzh.ch/furrer/software/spam/
 # written and maintained by Reinhard Furrer.
@@ -56,62 +56,6 @@ bdiag.spam <- function(...){
   }
 }
 
-# Draw from a multivariate normal:
-# (Algorithm 2.3 from Rue and Held, 2005)
-rmvnorm.spam <- function(n,mu=rep(0, nrow(Sigma)), Sigma, Rstruct=NULL, ...) {
-  # taken from ?chol.spam
-  
-  if (is(Rstruct,"spam.chol.NgPeyton"))
-    cholS <- update.spam.chol.NgPeyton( Rstruct, Sigma, ...)
-  else
-    cholS <- chol.spam( Sigma,...)
-  # cholS is the upper triangular part of the permutated matrix Sigma
-  iord <- ordering(cholS, inv=TRUE)
-
-  N <- dim(Sigma)[1]
-
-  R <- as.spam(cholS)
-  retval <- ( array(rnorm(n*N),c(n,N)) %*% R)[,iord,drop=F]
-     # It is often better to order the sample than the matrix
-     # R itself.
-  return(sweep(retval, 2, mu, "+"))
-}
-
-# Draw from a multivariate normal given a precision matrix:
-# (Algorithm 2.4 from Rue and Held, 2005)
-rmvnorm.prec <- function(n,mu=rep(0, nrow(Q)), Q, Rstruct=NULL, ...) {
-
-  if (is(Rstruct,"spam.chol.NgPeyton"))
-    R <- update.spam.chol.NgPeyton( Rstruct, Q, ...)
-  else
-    R <- chol(Q,...)
-  # R is the upper triangular part of the permutated matrix Sigma
-
-  N <- dim(Q)[1]
-  nu <- backsolve(R, array(rnorm(n*N),c(N,n)))
-  return(t(nu+mu))
-}
-
-
-# Draw from the canonical representation of a multivariate normal:
-# (Algorithm 2.5 from Rue and Held, 2005)
-rmvnorm.canonical <- function(n, b, Q, Rstruct=NULL, ...) {
-  N=dim(Q)[1]
-  if (is(Rstruct,"spam.chol.NgPeyton"))
-    R <- update.spam.chol.NgPeyton( Rstruct, Q, ...)
-  else
-    R <- chol(Q,...)
-
-  if(is(R,"spam.chol.NgPeyton")){
-     mu <- drop(solve.spam( R, b))	
-  } else {
-     mu <- backsolve( R, forwardsolve( t(R), b))
-  }
-  nu <- backsolve(R, array( rnorm(n*N), c(N, n)))
-  return(t(nu+mu))
-}
-
-
 
 adjacency.landkreis <- function(loc)
   # this reads the germany graph file provide by
